@@ -1,8 +1,7 @@
 import sys
 
-from dagster_graphql.schema.errors import DauphinPythonError
-
 from dagster.utils.error import serializable_error_info_from_exc_info
+from dagster_graphql.schema.errors import GraphenePythonError
 
 
 def test_python_error():
@@ -12,7 +11,7 @@ def test_python_error():
     try:
         func()
     except:  # pylint: disable=W0702
-        python_error = DauphinPythonError(serializable_error_info_from_exc_info(sys.exc_info()))
+        python_error = GraphenePythonError(serializable_error_info_from_exc_info(sys.exc_info()))
 
     assert python_error
     assert isinstance(python_error.message, str)
